==> haskell-tzdata-0.2.20221011.0-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tzdata.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tzdata
version:              0.2.20221011.0
visibility:           public
id:                   tzdata-0.2.20221011.0-yAHGVklIQ2DNv56jH8o5H
key:                  tzdata-0.2.20221011.0-yAHGVklIQ2DNv56jH8o5H
license:              Apache-2.0
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Mihaly Barasz, Gergely Risko
stability:            experimental
homepage:             https://github.com/ysangkok/haskell-tzdata
synopsis:             Time zone database (as files and as a module)
description:
    The goal of this package is to distribute the standard Time Zone
    Database in a cabal package, so that it can be used in Haskell
    programs uniformly on all platforms.

    This package currently ships the @2022e@ version of the time zone
    database.  The version of the time zone database shipped is always
    reflected in the version of this package: @x.y.YYYYMMDD.z@, then
    @YYYYMMDD@ is the official release date of time zone database.

    This version contains the "fat" variant of the time zone files (which is not
    the default for the upstream since @2020b@) to facilitate the transition. The
    next major version (@0.3@) will ship the "slim" variant.

    See: <http://www.iana.org/time-zones> for more info about the time
    zone database.

    See also the @tz@ package <http://hackage.haskell.org/package/tz> or
    the @timezone-olson@ and @timezone-series@ packages that provide
    facilities to /use/ the data shipped here. (The @tz@ package
    automatically installs this package.)

category:             Data
abi:                  3e81dcc21501d308651cb60c1fce10ff
exposed:              True
exposed-modules:      Data.Time.Zones.DB Data.Time.Zones.Files
hidden-modules:       Paths_tzdata
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tzdata-0.2.20221011.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tzdata-0.2.20221011.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tzdata
hs-libraries:         HStzdata-0.2.20221011.0-yAHGVklIQ2DNv56jH8o5H
depends:
    base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    deepseq-1.4.5.0 vector-0.13.0.0-80dNWv5W93FGfZf7Ao5mAf

haddock-interfaces:   /usr/share/doc/haskell-tzdata/html/tzdata.haddock
haddock-html:         /usr/share/doc/haskell-tzdata/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tzdata-0.2.20221129.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tzdata.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tzdata
version:              0.2.20221129.0
visibility:           public
id:                   tzdata-0.2.20221129.0-GpI4QYOIHjQ8uQ3SXyjq1M
key:                  tzdata-0.2.20221129.0-GpI4QYOIHjQ8uQ3SXyjq1M
license:              Apache-2.0
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Mihaly Barasz, Gergely Risko
stability:            experimental
homepage:             https://github.com/ysangkok/haskell-tzdata
synopsis:             Time zone database (as files and as a module)
description:
    The goal of this package is to distribute the standard Time Zone
    Database in a cabal package, so that it can be used in Haskell
    programs uniformly on all platforms.

    This package currently ships the @2022g@ version of the time zone
    database.  The version of the time zone database shipped is always
    reflected in the version of this package: @x.y.YYYYMMDD.z@, then
    @YYYYMMDD@ is the official release date of time zone database.

    This version contains the "fat" variant of the time zone files (which is not
    the default for the upstream since @2020b@) to facilitate the transition. The
    next major version (@0.3@) will ship the "slim" variant.

    See: <http://www.iana.org/time-zones> for more info about the time
    zone database.

    See also the @tz@ package <http://hackage.haskell.org/package/tz> or
    the @timezone-olson@ and @timezone-series@ packages that provide
    facilities to /use/ the data shipped here. (The @tz@ package
    automatically installs this package.)

category:             Data
abi:                  18afc50e314350767aaeb9d0166d3ac7
exposed:              True
exposed-modules:      Data.Time.Zones.DB Data.Time.Zones.Files
hidden-modules:       Paths_tzdata
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tzdata-0.2.20221129.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tzdata-0.2.20221129.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tzdata
hs-libraries:         HStzdata-0.2.20221129.0-GpI4QYOIHjQ8uQ3SXyjq1M
depends:
    base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    deepseq-1.4.5.0 vector-0.13.0.0-C4IY0qsV06C5Tx1gtETdzw

haddock-interfaces:   /usr/share/doc/haskell-tzdata/html/tzdata.haddock
haddock-html:         /usr/share/doc/haskell-tzdata/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
